/*
 *                 Sun Public License Notice
 *
 * The contents of this file are subject to the Sun Public License
 * Version 1.0 (the "License"). You may not use this file except in
 * compliance with the License. A copy of the License is available at
 * http://www.sun.com/
 *
 * The Original Code is NetBeans. The Initial Developer of the Original
 * Code is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 */


package com.sun.enterprise.tools.verifier.tests.appclient;

import com.sun.enterprise.tools.verifier.tests.VerifierTest;
import com.sun.enterprise.tools.verifier.tests.VerifierCheck;
import com.sun.enterprise.tools.verifier.Result;
import com.sun.enterprise.deployment.*;

/**
 * A container managed EM can only be of type JTA. Since JTA is not
 * required to be supported in ACC, in portability mode, we should report
 * a  failure if an appclient uses container managed em.
 *
 * @author Sanjeeb.Sahoo@Sun.COM
 */
public class ContainerManagedEM extends VerifierTest implements VerifierCheck {

    public Result check(Descriptor descriptor) {
        ApplicationClientDescriptor appClient = (ApplicationClientDescriptor) descriptor;
        Result result = getInitializedResult();
        addErrorDetails(result, getVerifierContext().getComponentNameConstructor());
        result.setStatus(Result.PASSED); // default status is PASSED
        if(this.getVerifierContext().isAppserverMode()) {
            // See GF issue #1284. We now support JTA in ACC.
            return result;
        }
        for(EntityManagerReferenceDescriptor emRef : appClient.getEntityManagerReferenceDescriptors()) {
            result.failed(smh.getLocalString(getClass().getName() + ".failed",
                    "Application client references a container managed entity manager with " +
                    "persistence-context-ref-name [ {0} ].",
                    new Object[]{emRef.getName()}));
        }

        return result;
    }

}
